Crate densha_macros_internal

Crate densha_macros_internal 

Attribute Macros

api
Attribute macro for defining API endpoints
config
Attribute macro for defining configuration
page
Attribute macro for defining page components
static_paths
Attribute macro for defining static paths for dynamic routes
static_props
Attribute macro for defining static props function for data fetching at build time